@@ -228,7 +228,7 @@ void MainWindow::uploadFile() {
 
     this->connect(m_cancelButton, SIGNAL(clicked()), transfer, SLOT(cancel()));
     this->connect(transfer, SIGNAL(progressChanged(int)), this, SLOT(onTransferProgressChanged(int)));
-    this->connect(transfer, SIGNAL(statusChanged(TransferStatus::Status)), this, SLOT(onTransferStatusChanged(TransferStatus::Status)));
+    this->connect(transfer, SIGNAL(statusChanged(FileTransfer::Status)), this, SLOT(onTransferStatusChanged(FileTransfer::Status)));
 }
 
 void MainWindow::downloadFile() {
@@ -238,7 +238,7 @@ void MainWindow::downloadFile() {
 
     this->connect(m_cancelButton, SIGNAL(clicked()), transfer, SLOT(cancel()));
     this->connect(transfer, SIGNAL(progressChanged(int)), this, SLOT(onTransferProgressChanged(int)));
-    this->connect(transfer, SIGNAL(statusChanged(TransferStatus::Status)), this, SLOT(onTransferStatusChanged(TransferStatus::Status)));
+    this->connect(transfer, SIGNAL(statusChanged(FileTransfer::Status)), this, SLOT(onTransferStatusChanged(FileTransfer::Status)));
 }
 
 void MainWindow::onUserReady(User *user) {
@@ -247,7 +247,7 @@ void MainWindow::onUserReady(User *user) {
     m_resultEdit->clear();
 
     switch (user->error()) {
-    case ReplyError::NoError:
+    case User::NoError:
         m_resultEdit->append(tr("Id: %1").arg(user->id()));
         m_resultEdit->append(tr("Name: %1").arg(user->name()));
         m_resultEdit->append(tr("Resource path: %1").arg(user->resourcePath()));
@@ -277,7 +277,7 @@ void MainWindow::onNodeReady(Node *node) {
     m_resultEdit->clear();
 
     switch (node->error()) {
-    case ReplyError::NoError:
+    case Node::NoError:
         m_resultEdit->append(tr("Path: %1").arg(node->path()));
         m_resultEdit->append(tr("Resource path: %1").arg(node->resourcePath()));
         m_resultEdit->append(tr("Content path: %1").arg(node->contentPath()));
@@ -318,7 +318,7 @@ void MainWindow::onNodeListReady(NodeList *nodes) {
     m_resultEdit->clear();
 
     switch (nodes->error()) {
-    case ReplyError::NoError:
+    case NodeList::NoError:
         foreach (Node *node, nodes->nodes()) {
             m_resultEdit->append(tr("Path: %1").arg(node->path()));
             m_resultEdit->append(tr("Resource path: %1").arg(node->resourcePath()));
@@ -366,7 +366,7 @@ void MainWindow::onReplyFinished(Reply *reply) {
     m_resultEdit->append(tr("Status: %1").arg(reply->status()));
 
     switch (reply->error()) {
-    case ReplyError::NoError:
+    case Reply::NoError:
         m_resultEdit->append(reply->resultString());
         break;
     default:
@@ -388,20 +388,20 @@ void MainWindow::onTransferProgressChanged(int progress) {
     m_resultEdit->append(tr("Progress: %1%").arg(progress));
 }
 
-void MainWindow::onTransferStatusChanged(TransferStatus::Status status) {
+void MainWindow::onTransferStatusChanged(FileTransfer::Status status) {
     if (FileTransfer *transfer = qobject_cast<FileTransfer*>(this->sender())) {
         switch (status) {
-        case TransferStatus::Completed:
+        case FileTransfer::Completed:
             m_actionButton->setEnabled(true);
             m_cancelButton->setEnabled(false);
             m_resultEdit->append(tr("Transfer completed successfully."));
             break;
-        case TransferStatus::Cancelled:
+        case FileTransfer::Cancelled:
             m_actionButton->setEnabled(true);
             m_cancelButton->setEnabled(false);
             m_resultEdit->append(tr("Transfer cancelled."));
             break;
-        case TransferStatus::Failed:
+        case FileTransfer::Failed:
             m_actionButton->setEnabled(true);
             m_cancelButton->setEnabled(false);
             m_resultEdit->append(tr("Error: %1").arg(transfer->errorString()));
