@@ -332,7 +332,7 @@ public slots:
 signals:
     void sizeChanged(qint64 size);
     void progressChanged(int progress);
-    void statusChanged(Status status);
+    void statusChanged(FileTransfer::Status status);
 
 private:
     explicit FileTransfer(FileTransferPrivate &d, QObject *parent = 0);
