@@ -27,10 +27,15 @@
 
 namespace QtUbuntuOne {
 
+#ifdef MEEGO_EDITION_HARMATTAN
+TransferUI::Client* FileTransferPrivate::m_tuiClient = 0;
+int FileTransferPrivate::m_tuiCount = 0;
+#endif
+
 FileTransferPrivate::FileTransferPrivate(FileTransfer *parent) :
     q_ptr(parent),
     m_reply(0),
-    m_transferType(TransferType::Download),
+    m_transferType(FileTransfer::Download),
     m_id(QString::number(QDateTime::currentMSecsSinceEpoch())),
     m_contentType("application/octet-stream"),
     m_size(0),
@@ -39,12 +44,34 @@ FileTransferPrivate::FileTransferPrivate(FileTransfer *parent) :
     m_progress(0),
     m_overwrite(false),
     m_public(false),
-    m_status(TransferStatus::Queued),
-    m_error(TransferError::NoError)
+    m_status(FileTransfer::Queued),
+    m_error(FileTransfer::NoError)
 {
+#ifdef MEEGO_EDITION_HARMATTAN
+    Q_Q(FileTransfer);
+    
+    if (!m_tuiClient) {
+        m_tuiClient = new TransferUI::Client;
+        m_tuiClient->init();
+    }
+
+    m_tuiCount++;
+    
+    m_tuiTransfer = m_tuiClient->registerTransfer(QString(), TransferUI::Client::TRANSFER_TYPES_DOWNLOAD);
+    m_tuiTransfer->waitForCommit();
+    m_tuiTransfer->setTargetName("Ubuntu One");
+    m_tuiTransfer->setIcon("icon-m-content-document");
+    m_tuiTransfer->setCanPause(true);
+    m_tuiTransfer->commit();
+    
+    q->connect(m_tuiTransfer, SIGNAL(start()), q, SLOT(queue()));
+    q->connect(m_tuiTransfer, SIGNAL(pause()), q, SLOT(pause()));
+    q->connect(m_tuiTransfer, SIGNAL(cancel()), q, SLOT(cancel()));
+    q->connect(m_tuiTransfer, SIGNAL(repairError()), q, SLOT(queue()));
+#endif
 }
 
-FileTransferPrivate::FileTransferPrivate(TransferType::Type transferType, const QString &contentPath, const QString &filePath, FileTransfer *parent) :
+FileTransferPrivate::FileTransferPrivate(FileTransfer::TransferType transferType, const QString &contentPath, const QString &filePath, FileTransfer *parent) :
     q_ptr(parent),
     m_reply(0),
     m_transferType(transferType),
@@ -58,9 +85,34 @@ FileTransferPrivate::FileTransferPrivate(TransferType::Type transferType, const
     m_progress(0),
     m_overwrite(false),
     m_public(false),
-    m_status(TransferStatus::Queued),
-    m_error(TransferError::NoError)
+    m_status(FileTransfer::Queued),
+    m_error(FileTransfer::NoError)
 {
+#ifdef MEEGO_EDITION_HARMATTAN
+    Q_Q(FileTransfer);
+    
+    if (!m_tuiClient) {
+        m_tuiClient = new TransferUI::Client;
+        m_tuiClient->init();
+    }
+
+    m_tuiCount++;
+    
+    m_tuiTransfer = m_tuiClient->registerTransfer(filePath.mid(filePath.lastIndexOf('/') + 1),
+                                                  transferType == FileTransfer::Upload ? TransferUI::Client::TRANSFER_TYPES_UPLOAD
+                                                                                       : TransferUI::Client::TRANSFER_TYPES_DOWNLOAD);
+
+    m_tuiTransfer->waitForCommit();
+    m_tuiTransfer->setTargetName("Ubuntu One");
+    m_tuiTransfer->setIcon("icon-m-content-document");
+    m_tuiTransfer->setCanPause(transferType == FileTransfer::Download);
+    m_tuiTransfer->commit();
+    
+    q->connect(m_tuiTransfer, SIGNAL(start()), q, SLOT(queue()));
+    q->connect(m_tuiTransfer, SIGNAL(pause()), q, SLOT(pause()));
+    q->connect(m_tuiTransfer, SIGNAL(cancel()), q, SLOT(cancel()));
+    q->connect(m_tuiTransfer, SIGNAL(repairError()), q, SLOT(queue()));
+#endif
 }
 
 FileTransferPrivate::~FileTransferPrivate() {
@@ -68,14 +120,49 @@ FileTransferPrivate::~FileTransferPrivate() {
         delete m_reply;
         m_reply = 0;
     }
+#ifdef MEEGO_EDITION_HARMATTAN
+    if (m_tuiTransfer) {
+        if (m_tuiClient) {
+            m_tuiClient->removeTransfer(m_tuiTransfer->transferId());
+        }
+
+        delete m_tuiTransfer;
+        m_tuiTransfer = 0;
+
+        m_tuiCount--;
+
+        if ((!m_tuiCount) && (m_tuiClient)) {
+            delete m_tuiClient;
+            m_tuiClient = 0;
+        }
+    }
+#endif
 }
 
-TransferType::Type FileTransferPrivate::transferType() const {
+FileTransfer::TransferType FileTransferPrivate::transferType() const {
     return m_transferType;
 }
 
-void FileTransferPrivate::setTransferType(TransferType::Type type) {
+void FileTransferPrivate::setTransferType(FileTransfer::TransferType type) {
     m_transferType = type;
+#ifdef MEEGO_EDITION_HARMATTAN
+    if (m_tuiTransfer) {
+        switch (type) {
+        case FileTransfer::Upload:
+            m_tuiTransfer->waitForCommit();
+            m_tuiTransfer->setTransferType(TransferUI::Client::TRANSFER_TYPES_UPLOAD);
+            m_tuiTransfer->setCanPause(false);
+            m_tuiTransfer->commit();
+            return;
+        default:
+            m_tuiTransfer->waitForCommit();
+            m_tuiTransfer->setTransferType(TransferUI::Client::TRANSFER_TYPES_DOWNLOAD);
+            m_tuiTransfer->setCanPause(true);
+            m_tuiTransfer->commit();
+            return;
+        }
+    }
+#endif
 }
 
 QString FileTransferPrivate::id() const {
@@ -108,6 +195,11 @@ QString FileTransferPrivate::filePath() const {
 
 void FileTransferPrivate::setFilePath(const QString &path) {
     m_filePath = path;
+#ifdef MEEGO_EDITION_HARMATTAN
+    if (m_tuiTransfer) {
+        m_tuiTransfer->setName(path.mid(path.lastIndexOf('/') + 1));
+    }
+#endif
 }
 
 QString FileTransferPrivate::contentType() const {
@@ -124,10 +216,15 @@ qint64 FileTransferPrivate::size() const {
 
 void FileTransferPrivate::setSize(qint64 size) {
     Q_Q(FileTransfer);
-
+    
     if (size != this->size()) {
         m_size = size;
         emit q->sizeChanged(size);
+#ifdef MEEGO_EDITION_HARMATTAN
+        if (m_tuiTransfer) {
+            m_tuiTransfer->setSize(size);
+        }
+#endif
     }
 }
 
@@ -149,10 +246,17 @@ int FileTransferPrivate::progress() const {
 
 void FileTransferPrivate::setProgress(int progress) {
     Q_Q(FileTransfer);
-
+    
     if (progress != this->progress()) {
         m_progress = progress;
         emit q->progressChanged(progress);
+#ifdef MEEGO_EDITION_HARMATTAN
+        if ((m_tuiClient) && (m_tuiClient->isTUIVisible())) {
+            if (m_tuiTransfer) {
+                m_tuiTransfer->setProgress(float(progress) / 100);
+            }
+        }
+#endif
     }
 }
 
@@ -172,24 +276,73 @@ void FileTransferPrivate::setPublic(bool isPublic) {
     m_public = isPublic;
 }
 
-TransferStatus::Status FileTransferPrivate::status() const {
+FileTransfer::Status FileTransferPrivate::status() const {
     return m_status;
 }
 
-void FileTransferPrivate::setStatus(TransferStatus::Status status) {
+void FileTransferPrivate::setStatus(FileTransfer::Status status) {
     Q_Q(FileTransfer);
-
+    
     if (status != this->status()) {
         m_status = status;
+#ifdef MEEGO_EDITION_HARMATTAN
+        switch (status) {
+        case FileTransfer::Queued:
+            if (m_tuiTransfer) m_tuiTransfer->setPending(this->statusString());
+            break;
+        case FileTransfer::Connecting:
+        case FileTransfer::Downloading:
+        case FileTransfer::Uploading:
+            if (m_tuiTransfer) m_tuiTransfer->markResumed();
+            break;
+        case FileTransfer::Completed:
+            if (m_tuiTransfer) m_tuiTransfer->markCompleted();
+            break;
+        case FileTransfer::Paused:
+            if (m_tuiTransfer) m_tuiTransfer->markPaused();
+            break;
+        case FileTransfer::Cancelled:
+            if (m_tuiTransfer) m_tuiTransfer->markCancelled();
+            break;
+        case FileTransfer::Failed:
+            if (m_tuiTransfer) m_tuiTransfer->markRepairableFailure(this->statusString(), this->errorString(), QObject::tr("Retry"));
+            break;
+        default:
+            break;
+        }
+#endif
         emit q->statusChanged(status);
     }
 }
 
-TransferError::Error FileTransferPrivate::error() const {
+QString FileTransferPrivate::statusString() const {
+    switch (this->status()) {
+    case FileTransfer::Queued:
+        return QObject::tr("Queued");
+    case FileTransfer::Paused:
+        return QObject::tr("Paused");
+    case FileTransfer::Connecting:
+        return QObject::tr("Connecting");
+    case FileTransfer::Downloading:
+        return QObject::tr("Downloading");
+    case FileTransfer::Uploading:
+        return QObject::tr("Uploading");
+    case FileTransfer::Cancelled:
+        return QObject::tr("Cancelled");
+    case FileTransfer::Failed:
+        return QObject::tr("Failed");
+    case FileTransfer::Completed:
+        return QObject::tr("Completed");
+    default:
+        return QObject::tr("Unknown");
+    }
+}
+
+FileTransfer::Error FileTransferPrivate::error() const {
     return m_error;
 }
 
-void FileTransferPrivate::setError(TransferError::Error error) {
+void FileTransferPrivate::setError(FileTransfer::Error error) {
     m_error = error;
 }
 
@@ -203,44 +356,44 @@ void FileTransferPrivate::setErrorString(const QString &errorString) {
 
 void FileTransferPrivate::start() {
     if (this->contentPath().isEmpty()) {
-        this->setError(TransferError::ResourceError);
+        this->setError(FileTransfer::ResourceError);
         this->setErrorString(QObject::tr("No resource path specified"));
-        this->setStatus(TransferStatus::Failed);
+        this->setStatus(FileTransfer::Failed);
         return;
     }
-
+    
     switch (this->transferType()) {
-    case TransferType::Upload:
+    case FileTransfer::Upload:
         m_file.setFileName(this->filePath());
-
+        
         if (!m_file.open(QIODevice::ReadOnly)) {
-            this->setError(TransferError::FileError);
+            this->setError(FileTransfer::FileError);
             this->setErrorString(QObject::tr("Cannot open file %1: %2").arg(m_file.fileName()).arg(m_file.errorString()));
-            this->setStatus(TransferStatus::Failed);
+            this->setStatus(FileTransfer::Failed);
             return;
         }
-
+        
         this->setUrl(QUrl(CONTENT_ROOT_FILES + this->contentPath()));
         this->setSize(m_file.size());
         this->performUpload();
         break;
     default:
         if (!QDir().mkpath(this->filePath().left(this->filePath().lastIndexOf('/')))) {
-            this->setError(TransferError::FileError);
+            this->setError(FileTransfer::FileError);
             this->setErrorString(QObject::tr("Cannot create directory %1").arg(this->filePath().left(this->filePath().lastIndexOf('/'))));
-            this->setStatus(TransferStatus::Failed);
+            this->setStatus(FileTransfer::Failed);
             return;
         }
-
+        
         m_file.setFileName(this->filePath().endsWith(".qubuntuone") ? this->filePath() : this->filePath() + ".qubuntuone");
-
+        
         if (!m_file.open(m_file.exists() ? QIODevice::Append : QIODevice::WriteOnly)) {
-            this->setError(TransferError::FileError);
+            this->setError(FileTransfer::FileError);
             this->setErrorString(QObject::tr("Cannot open file %1: %2").arg(m_file.fileName()).arg(m_file.errorString()));
-            this->setStatus(TransferStatus::Failed);
+            this->setStatus(FileTransfer::Failed);
             return;
         }
-
+        
         this->setResumePosition(m_file.size());
         this->setUrl(QUrl(CONTENT_ROOT_FILES + this->contentPath()));
         //        this->performDownload();
@@ -251,9 +404,9 @@ void FileTransferPrivate::start() {
 
 void FileTransferPrivate::queue() {
     switch(this->status()) {
-    case TransferStatus::Paused:
-    case TransferStatus::Failed:
-        this->setStatus(TransferStatus::Queued);
+    case FileTransfer::Paused:
+    case FileTransfer::Failed:
+        this->setStatus(FileTransfer::Queued);
         return;
     default:
         return;
@@ -262,43 +415,43 @@ void FileTransferPrivate::queue() {
 
 void FileTransferPrivate::pause() {
     switch(this->transferType()) {
-    case TransferType::Upload:
+    case FileTransfer::Upload:
         return;
     default:
         break;
     }
-
+    
     if (m_reply) {
         m_reply->abort();
     }
-
-    this->setStatus(TransferStatus::Paused);
+    
+    this->setStatus(FileTransfer::Paused);
 }
 
 void FileTransferPrivate::cancel() {
     if (m_reply) {
         m_reply->abort();
     }
-
+    
     switch (this->transferType()) {
-    case TransferType::Download:
+    case FileTransfer::Download:
         if (QFile::exists(this->filePath() + ".qubuntuone")) {
             QFile::remove(this->filePath() + ".qubuntuone");
         }
-
+        
         break;
     default:
         break;
     }
-
-    this->setStatus(TransferStatus::Cancelled);
+    
+    this->setStatus(FileTransfer::Cancelled);
 }
 
 void FileTransferPrivate::performUpload() {
     Q_Q(FileTransfer);
-
-    this->setStatus(TransferStatus::Uploading);
-
+    
+    this->setStatus(FileTransfer::Uploading);
+    
     QNetworkRequest request(this->url());
     request.setHeader(QNetworkRequest::ContentTypeHeader, this->contentType());
     request.setHeader(QNetworkRequest::ContentLengthHeader, this->size());
@@ -312,22 +465,22 @@ void FileTransferPrivate::performUpload() {
 
 void FileTransferPrivate::performDownload() {
     Q_Q(FileTransfer);
-
-    this->setStatus(TransferStatus::Downloading);
-
+    
+    this->setStatus(FileTransfer::Downloading);
+    
     QNetworkRequest request(this->url());
-
+    
     if (this->resumePosition() > 0) {
         request.setRawHeader("Range", QByteArray::number(this->resumePosition()) + "-");
     }
-
+    
     request.setRawHeader("Authorization", Authentication::getOAuthHeader("GET", this->url().toString(QUrl::RemoveQuery).toUtf8().toPercentEncoding(":/~_?="), QMap<QString, QString>()));
     request.setRawHeader("User-Agent", "QUbuntuOne (Qt)");
     m_reply = NetworkAccessManager::instance()->get(request);
     q->connect(m_reply, SIGNAL(downloadProgress(qint64,qint64)), q, SLOT(_q_onProgressChanged(qint64,qint64)));
     q->connect(m_reply, SIGNAL(readyRead()), q, SLOT(_q_onReadyRead()));
     q->connect(m_reply, SIGNAL(finished()), q, SLOT(_q_onDownloadFinished()));
-
+    
     if (this->size() <= 0) {
         q->connect(m_reply, SIGNAL(metaDataChanged()), q, SLOT(_q_onMetaDataChanged()));
     }
@@ -337,37 +490,37 @@ void FileTransferPrivate::getMetaData() {
     /* Temporary fix. The Ubuntu One API does not return a Content-Length header when downloading,
        so get the metadata before downloading.
     */
-
+    
     Q_Q(FileTransfer);
-
-    this->setStatus(TransferStatus::Connecting);
-
+    
+    this->setStatus(FileTransfer::Connecting);
+    
     Node *node = Files::getNode(this->contentPath().remove(0, 8));
     q->connect(node, SIGNAL(ready(Node*)), q, SLOT(_q_setMetaData(Node*)));
 }
 
 void FileTransferPrivate::_q_setMetaData(Node *node) {
     switch (node->error()) {
-    case ReplyError::NoError:
+    case Node::NoError:
         this->setSize(node->size());
         break;
     default:
         break;
     }
-
+    
     this->performDownload();
-
+    
     node->deleteLater();
 }
 
 void FileTransferPrivate::_q_onMetaDataChanged() {
     if (m_reply) {
         qint64 size = m_reply->header(QNetworkRequest::ContentLengthHeader).toLongLong();
-
+        
         if (size <= 0) {
             size = m_reply->rawHeader("Content-Length").toLongLong();
         }
-
+        
         if (size > 0) {
             this->setSize(size);
         }
@@ -376,9 +529,9 @@ void FileTransferPrivate::_q_onMetaDataChanged() {
 
 void FileTransferPrivate::_q_onProgressChanged(qint64 transferred, qint64 total) {
     Q_UNUSED(total)
-
+    
     m_transferredBytes = transferred;
-
+    
     if (this->size() > 0) {
         this->setProgress(this->position() * 100 / this->size());
     }
@@ -392,10 +545,10 @@ void FileTransferPrivate::_q_onReadyRead() {
 
 void FileTransferPrivate::_q_onUploadFinished() {
     m_file.close();
-
+    
     if (m_reply) {
         QUrl redirect = m_reply->attribute(QNetworkRequest::RedirectionTargetAttribute).toUrl();
-
+        
         if (!redirect.isEmpty()) {
             m_reply->deleteLater();
             m_reply = 0;
@@ -403,40 +556,40 @@ void FileTransferPrivate::_q_onUploadFinished() {
             this->performUpload();
             return;
         }
-
+        
         switch (m_reply->error()) {
         case QNetworkReply::NoError:
             break;
         case QNetworkReply::OperationCanceledError:
             return;
         default:
-            this->setError(TransferError::Error(m_reply->error()));
+            this->setError(FileTransfer::Error(m_reply->error()));
             this->setErrorString(m_reply->errorString());
-            this->setStatus(TransferStatus::Failed);
+            this->setStatus(FileTransfer::Failed);
             m_reply->deleteLater();
             m_reply = 0;
             return;
         }
-
+        
         bool ok;
         QString response(m_reply->readAll());
         QVariant result = QtJson::Json::parse(response, ok);
-
+        
         m_reply->deleteLater();
         m_reply = 0;
-
+        
         if (ok) {
             if (this->isPublic()) {
                 this->publishFile(result.toMap().value("resource_path").toString());
             }
             else {
-                this->setStatus(TransferStatus::Completed);
+                this->setStatus(FileTransfer::Completed);
             }
         }
         else {
-            this->setError(TransferError::ParserError);
+            this->setError(FileTransfer::ParserError);
             this->setErrorString(QObject::tr("Cannot parse server response"));
-            this->setStatus(TransferStatus::Failed);
+            this->setStatus(FileTransfer::Failed);
         }
     }
 }
@@ -444,7 +597,7 @@ void FileTransferPrivate::_q_onUploadFinished() {
 void FileTransferPrivate::_q_onDownloadFinished() {
     if (m_reply) {
         QUrl redirect = m_reply->attribute(QNetworkRequest::RedirectionTargetAttribute).toUrl();
-
+        
         if (!redirect.isEmpty()) {
             m_reply->deleteLater();
             m_reply = 0;
@@ -452,18 +605,18 @@ void FileTransferPrivate::_q_onDownloadFinished() {
             this->performDownload();
             return;
         }
-
+        
         switch (m_reply->error()) {
         case QNetworkReply::NoError:
             switch (this->transferType()) {
-            case TransferType::Download:
+            case FileTransfer::Download:
                 this->renameDownloadedFile();
                 break;
             default:
-                this->setStatus(TransferStatus::Completed);
+                this->setStatus(FileTransfer::Completed);
                 break;
             }
-
+            
             break;
         case QNetworkReply::OperationCanceledError:
             m_file.close();
@@ -471,12 +624,12 @@ void FileTransferPrivate::_q_onDownloadFinished() {
             m_reply = 0;
             return;
         default:
-            this->setError(TransferError::Error(m_reply->error()));
+            this->setError(FileTransfer::Error(m_reply->error()));
             this->setErrorString(m_reply->errorString());
-            this->setStatus(TransferStatus::Failed);
+            this->setStatus(FileTransfer::Failed);
             break;
         }
-
+        
         m_file.close();
         m_reply->deleteLater();
         m_reply = 0;
@@ -485,7 +638,7 @@ void FileTransferPrivate::_q_onDownloadFinished() {
 
 void FileTransferPrivate::renameDownloadedFile() {
     QString fileName = this->filePath();
-
+    
     if (this->overwriteExistingFile()) {
         if ((!QFile::exists(fileName)) || (QFile::remove(fileName))) {
             m_file.rename(fileName);
@@ -494,35 +647,35 @@ void FileTransferPrivate::renameDownloadedFile() {
     else {
         int lastDot = fileName.lastIndexOf('.');
         int i = 1;
-
+        
         while ((!m_file.rename(fileName)) && (i < 100)) {
             fileName = QString("%1(%2)%3").arg(this->filePath().left(lastDot)).arg(i).arg(this->filePath().mid(lastDot));
             i++;
         }
     }
-
-    this->setStatus(TransferStatus::Completed);
+    
+    this->setStatus(FileTransfer::Completed);
 }
 
 void FileTransferPrivate::publishFile(const QString &resourcePath) {
     Q_Q(FileTransfer);
-
+    
     Node *node = Files::setFilePublic(resourcePath, true);
     q->connect(node, SIGNAL(ready(Node*)), q, SLOT(_q_onFilePublished(Node*)));
 }
 
 void FileTransferPrivate::_q_onFilePublished(Node *node) {
     switch (node->error()) {
-    case ReplyError::NoError:
-        this->setStatus(TransferStatus::Completed);
+    case Node::NoError:
+        this->setStatus(FileTransfer::Completed);
         break;
     default:
-        this->setError(TransferError::ResourceError);
+        this->setError(FileTransfer::ResourceError);
         this->setErrorString(node->errorString());
-        this->setStatus(TransferStatus::Failed);
+        this->setStatus(FileTransfer::Failed);
         break;
     }
-
+    
     node->deleteLater();
 }
 
