@@ -220,7 +220,7 @@ signals:
      *
      * \param status
      */
-    void statusChanged(Status status);
+    void statusChanged(MusicStream::Status status);
 
 private:
     explicit MusicStream(MusicStreamPrivate &d, QObject *parent = 0);
