@@ -31,8 +31,8 @@ MusicStreamPrivate::MusicStreamPrivate(MusicStream *parent) :
     m_size(0),
     m_resumePosition(0),
     m_transferredBytes(0),
-    m_status(StreamStatus::Stopped),
-    m_error(StreamError::NoError),
+    m_status(MusicStream::Stopped),
+    m_error(MusicStream::NoError),
     m_readPos(0),
     m_writePos(0)
 {
@@ -46,8 +46,8 @@ MusicStreamPrivate::MusicStreamPrivate(const QUrl &url, const QString &filePath,
     m_size(0),
     m_resumePosition(0),
     m_transferredBytes(0),
-    m_status(StreamStatus::Stopped),
-    m_error(StreamError::NoError),
+    m_status(MusicStream::Stopped),
+    m_error(MusicStream::NoError),
     m_readPos(0),
     m_writePos(0)
 {
@@ -104,11 +104,11 @@ void MusicStreamPrivate::setResumePosition(qint64 position) {
     m_resumePosition = position;
 }
 
-StreamStatus::Status MusicStreamPrivate::status() const {
+MusicStream::Status MusicStreamPrivate::status() const {
     return m_status;
 }
 
-void MusicStreamPrivate::setStatus(StreamStatus::Status status) {
+void MusicStreamPrivate::setStatus(MusicStream::Status status) {
     Q_Q(MusicStream);
 
     if (status != this->status()) {
@@ -117,11 +117,11 @@ void MusicStreamPrivate::setStatus(StreamStatus::Status status) {
     }
 }
 
-StreamError::Error MusicStreamPrivate::error() const {
+MusicStream::Error MusicStreamPrivate::error() const {
     return m_error;
 }
 
-void MusicStreamPrivate::setError(StreamError::Error error) {
+void MusicStreamPrivate::setError(MusicStream::Error error) {
     m_error = error;
 }
 
@@ -212,15 +212,15 @@ void MusicStreamPrivate::start() {
 
     if (!QDir().mkpath(this->filePath().left(this->filePath().lastIndexOf('/')))) {
         q->setErrorString(QObject::tr("Cannot create directory %1").arg(this->filePath().left(this->filePath().lastIndexOf('/'))));
-        this->setError(StreamError::FileError);
-        this->setStatus(StreamStatus::Error);
+        this->setError(MusicStream::FileError);
+        this->setStatus(MusicStream::Failed);
         return;
     }
 
     if (!this->open(QIODevice::ReadWrite)) {
         q->setErrorString(QObject::tr("Cannot open file %1: %2").arg(this->filePath()).arg(m_file.errorString()));
-        this->setError(StreamError::FileError);
-        this->setStatus(StreamStatus::Error);
+        this->setError(MusicStream::FileError);
+        this->setStatus(MusicStream::Failed);
         return;
     }
 
@@ -228,10 +228,10 @@ void MusicStreamPrivate::start() {
     this->performDownload(this->url());
 
     if (this->streamPosition() > BUFFER_SIZE) {
-        this->setStatus(StreamStatus::Ready);
+        this->setStatus(MusicStream::Ready);
     }
     else {
-        this->setStatus(StreamStatus::Buffering);
+        this->setStatus(MusicStream::Buffering);
     }
 }
 
@@ -297,8 +297,8 @@ void MusicStreamPrivate::_q_onReadyRead() {
             emit q->readyRead();
 
             switch (this->status()) {
-            case StreamStatus::Buffering:
-                this->setStatus(StreamStatus::Ready);
+            case MusicStream::Buffering:
+                this->setStatus(MusicStream::Ready);
                 return;
             default:
                 return;
@@ -326,13 +326,13 @@ void MusicStreamPrivate::_q_onDownloadFinished() {
         case QNetworkReply::OperationCanceledError:
             m_reply->deleteLater();
             m_reply = 0;
-            this->setStatus(StreamStatus::Stopped);
+            this->setStatus(MusicStream::Stopped);
             return;
         default:
             this->close();
             q->setErrorString(m_reply->errorString());
-            this->setError(StreamError::Error(m_reply->error()));
-            this->setStatus(StreamStatus::Error);
+            this->setError(MusicStream::Error(m_reply->error()));
+            this->setStatus(MusicStream::Failed);
             m_reply->deleteLater();
             m_reply = 0;
             return;
@@ -342,7 +342,7 @@ void MusicStreamPrivate::_q_onDownloadFinished() {
     m_reply->deleteLater();
     m_reply = 0;
 
-    this->setStatus(StreamStatus::Finished);
+    this->setStatus(MusicStream::Finished);
 }
 
 }
